<?php

namespace FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab;
use FiloBlu\Flow\Helper\Data;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Cms\Model\Page;
use Magento\Framework\Data\Form;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Registry;

/**
 * Class Connector
 * @package FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab
 */
class Connector extends Generic implements TabInterface
{

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @param Context $context
     * @param Registry $registry
     * @param FormFactory $formFactory
     * @param Data $helper
     * @param array $data
     */

    public function __construct(
        Context $context,
        Registry $registry,
        FormFactory $formFactory,
        Data $helper,
        array $data = array()
    )
    {
        $this->helper = $helper;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('Connector');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return __('connector');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Prepare form
     *
     * @return $this
     * @throws LocalizedException
     */
    protected function _prepareForm()
    {
        /* @var $model Page */
        $model = $this->_coreRegistry->registry('flow_channel');
        /** @var Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('page_');

        $fieldset_connector = $form->addFieldset('connector_fieldset', array('legend' => __('Connector')));

        $fieldset_connector->addField("type", "text", array(
            "label" => __("Type"),
            "name" => "connector[type]",
        ));

        $fieldset_connector->addField("host", "text", array(
            "label" => __("Host"),
            "name" => "connector[host]",
        ));

        $fieldset_connector->addField("username", "text", array(
            "label" => __("Username"),
            "name" => "connector[username]",
        ));

        $fieldset_connector->addField("password", "text", array(
            "label" => __("Password"),
            "name" => "connector[password]",
        ));

        $fieldset_connector->addField("passive", "select", array(
            "label" => __("Passive Mode"),
            "name" => "connector[passive]",
            'values' => array('0' => 'No', '1' => 'Yes'),
        ));

        $fieldset_connector->addField("ftp_dir", "text", array(
            "label" => __("Ftp Dir"),
            "name" => "connector[ftp_dir]",
        ));

        $fieldset_connector->addField("local_dir", "text", array(
            "label" => __("Local Dir"),
            "name" => "connector[local_dir]",
        ));

        $fieldset_connector->addField("regex", "text", array(
            "label" => __("File Mask"),
            "name" => "connector[regex]",
        ));

        $form->setValues($model->getData('connector'));
        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }
}
