<?php

namespace FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab;

use FiloBlu\Flow\Block\Adminhtml\Channel\Renderer\Textjson;
use FiloBlu\Flow\Helper\Data;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Cms\Model\Page;
use Magento\Framework\Data\Form;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Registry;
use Magento\Store\Model\System\Store;

/**
 * Class Map
 * @package FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab
 */
class Map extends Generic implements TabInterface
{
    /**
     * @var Store
     */
    protected $_systemStore;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @param Context $context
     * @param Registry $registry
     * @param FormFactory $formFactory
     * @param Store $systemStore
     * @param Data $helper
     * @param array $data
     */

    public function __construct(
        Context $context,
        Registry $registry,
        FormFactory $formFactory,
        Store $systemStore,
        Data $helper,
        array $data = []
    )
    {
        $this->_systemStore = $systemStore;
        $this->helper = $helper;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('Map');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return __('map');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Prepare form
     *
     * @return $this
     * @throws LocalizedException
     */
    protected function _prepareForm()
    {
        /* @var $model Page */
        $model = $this->_coreRegistry->registry('flow_channel');

        /** @var Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('page_');

        $fieldset_map = $form
            ->addFieldset('map_fieldset', ['legend' => __('Map')])
            ->addType(
                'textjson',
                Textjson::class
            );

        // TODO:
        // - use uiComonent based form
        // - use switcherConfig to hide map textarea conditionally

        $fieldset_map->addField('use_map', 'select', [
            'label' => __('Use mapping file'),
            'name' => 'use_map',
            'values' => ['0' => 'No', '1' => 'Yes'],
            'after_element_html' => $this->addJsDependency()
        ]);

        $fieldset_map->addField('map', 'textjson', [
            'label' => __('Map JSON'),
            'name' => 'map',
            'rows' => 50,
            'cols' => 40
        ]);

        $form->setValues($model->getData());
        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * @return string
     */
    private function addJsDependency()
    {
        return '<script>
            require([\'jquery\'], function($) {

                $(\'#page_use_map\').on(\'change\', function() {
                  var e = $(\'[data-ui-id="flow-channel-edit-tab-map-fieldset-element-form-field-map"]\');
                  ($(this).val()>0)?e.show():e.hide();
                });
                
                $(\'document\').ready(function () { $(\'#page_use_map\').trigger(\'change\'); });
            }
        );
      </script>';
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }
}
